==> alloy-ui-3.0.2-deprecated.1.jar: META-INF/resources/webjars/alloy-ui/3.0.2-deprecated.1/src/aui-button/HISTORY.md <==
# AUI Button

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-button).

## @VERSION@

* [AUI-2035](https://issues.liferay.com/browse/AUI-2035) AUI Button should have an option to don't add .btn-default and also .btn default classes
* [AUI-1899](https://issues.liferay.com/browse/AUI-1899) Improve Form Builder visual interface
* [AUI-1806](https://issues.liferay.com/browse/AUI-1806) Add button to cancel editing/creating a field
* [AUI-1793](https://issues.liferay.com/browse/AUI-1793) Fix date field bug with the boolean data editors
* [AUI-1724](https://issues.liferay.com/browse/AUI-1724) Improve aui-boolean-data-editor's appearance
* [AUI-1543](https://issues.liferay.com/browse/AUI-1543) Make aui-button accessible

## [3.0.1](https://github.com/liferay/alloy-ui/releases/tag/3.0.1)

No changes.

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1543](https://issues.liferay.com/browse/AUI-1543) Make aui-button accessible
* [AUI-1286](https://issues.liferay.com/browse/AUI-1286) Input with AUI button search cancel immediately loses focus
* [AUI-1281](https://issues.liferay.com/browse/AUI-1281) Button search cancel module misspositioning icon
* [AUI-1287](https://issues.liferay.com/browse/AUI-1287) Wrong css formatting when running "grunt format"
* [AUI-1174](https://issues.liferay.com/browse/AUI-1174) Validate source code with JSHint
* [AUI-1284](https://issues.liferay.com/browse/AUI-1284) Use cssClass attribute from WidgetCssClass instead of separated attributes for CSS class names in Button
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1267](https://issues.liferay.com/browse/AUI-1267) Move CSS classes from Alloy Bootstrap to AlloyUI
* [AUI-1248](https://issues.liferay.com/browse/AUI-1248) Allow users to request buttons to not have the btn-default class
* [AUI-1240](https://issues.liferay.com/browse/AUI-1240) Remove .container-fluid because everything is fluid on Bootstrap 3
* [AUI-1239](https://issues.liferay.com/browse/AUI-1239) Change grid system from .row-fluid to .row on Bootstrap 3
* [AUI-1235](https://issues.liferay.com/browse/AUI-1235) Change grid system from .span-* to .col-[lg|md|sm]-* on Bootstrap 3
* [AUI-1220](https://issues.liferay.com/browse/AUI-1220) Add .btn-default to .btn elements with no other color on Bootstrap 3
* [AUI-1223](https://issues.liferay.com/browse/AUI-1223) Use <span> instead of <i> when creating icons on Bootstrap 3
* [AUI-1224](https://issues.liferay.com/browse/AUI-1224) Add .glyphicon and change prefix from .icon-* to .glyphicon-* on Bootstrap 3

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1211](https://issues.liferay.com/browse/AUI-1211) Fix Y.Button duplicated icon due labelHTML added by YUI 3.15.0
* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
* [AUI-1161](https://issues.liferay.com/browse/AUI-1161) Search Button Cancel doesn't stay with input when input is removed from and placed back in DOM
* [AUI-1286](https://issues.liferay.com/browse/AUI-1286) Input with AUI button search cancel immediately loses focus

==> alloy-ui-3.0.3-deprecated.1.jar: META-INF/resources/webjars/alloy-ui/3.0.3-deprecated.1/src/aui-button/HISTORY.md <==
# AUI Button

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-button).

## @VERSION@

No registries yet.

## [3.0.3](https://github.com/liferay/alloy-ui/releases/tag/3.0.3)

No changes.

## [3.0.2](https://github.com/liferay/alloy-ui/releases/tag/3.0.2)

* [AUI-2035](https://issues.liferay.com/browse/AUI-2035) AUI Button should have an option to don't add .btn-default and also .btn default classes
* [AUI-1899](https://issues.liferay.com/browse/AUI-1899) Improve Form Builder visual interface
* [AUI-1806](https://issues.liferay.com/browse/AUI-1806) Add button to cancel editing/creating a field
* [AUI-1793](https://issues.liferay.com/browse/AUI-1793) Fix date field bug with the boolean data editors
* [AUI-1724](https://issues.liferay.com/browse/AUI-1724) Improve aui-boolean-data-editor's appearance
* [AUI-1543](https://issues.liferay.com/browse/AUI-1543) Make aui-button accessible

## [3.0.1](https://github.com/liferay/alloy-ui/releases/tag/3.0.1)

No changes.

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1543](https://issues.liferay.com/browse/AUI-1543) Make aui-button accessible
* [AUI-1286](https://issues.liferay.com/browse/AUI-1286) Input with AUI button search cancel immediately loses focus
* [AUI-1281](https://issues.liferay.com/browse/AUI-1281) Button search cancel module misspositioning icon
* [AUI-1287](https://issues.liferay.com/browse/AUI-1287) Wrong css formatting when running "grunt format"
* [AUI-1174](https://issues.liferay.com/browse/AUI-1174) Validate source code with JSHint
* [AUI-1284](https://issues.liferay.com/browse/AUI-1284) Use cssClass attribute from WidgetCssClass instead of separated attributes for CSS class names in Button
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1267](https://issues.liferay.com/browse/AUI-1267) Move CSS classes from Alloy Bootstrap to AlloyUI
* [AUI-1248](https://issues.liferay.com/browse/AUI-1248) Allow users to request buttons to not have the btn-default class
* [AUI-1240](https://issues.liferay.com/browse/AUI-1240) Remove .container-fluid because everything is fluid on Bootstrap 3
* [AUI-1239](https://issues.liferay.com/browse/AUI-1239) Change grid system from .row-fluid to .row on Bootstrap 3
* [AUI-1235](https://issues.liferay.com/browse/AUI-1235) Change grid system from .span-* to .col-[lg|md|sm]-* on Bootstrap 3
* [AUI-1220](https://issues.liferay.com/browse/AUI-1220) Add .btn-default to .btn elements with no other color on Bootstrap 3
* [AUI-1223](https://issues.liferay.com/browse/AUI-1223) Use <span> instead of <i> when creating icons on Bootstrap 3
* [AUI-1224](https://issues.liferay.com/browse/AUI-1224) Add .glyphicon and change prefix from .icon-* to .glyphicon-* on Bootstrap 3

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1211](https://issues.liferay.com/browse/AUI-1211) Fix Y.Button duplicated icon due labelHTML added by YUI 3.15.0
* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
* [AUI-1161](https://issues.liferay.com/browse/AUI-1161) Search Button Cancel doesn't stay with input when input is removed from and placed back in DOM
* [AUI-1286](https://issues.liferay.com/browse/AUI-1286) Input with AUI button search cancel immediately loses focus
